from distutils.core import setup

setup(
	name			=	'nester_rc54',
	version 		=	'1.2.0',
	py_modules		=	['nester_rc54'],
	author			=	'rchilders',
	author_email	=	'rchilders54@gmail.com',
	url				=	'http://richardchilders.ca',
	description		=	'A simple printer of nested lists',
	)